@@ -229,7 +229,8 @@ The next time the file is loaded, it will then be in EMaxima mode"
       (if (and found
                (re-search-forward emaxima-any-cell-end-regexp 
                                   (point-max) t)) ;\endmaxima
-          (setq found (point))))
+          (setq found (point))
+	(setq found nil)))        ; No \endmaxima
     (save-excursion
         (if (and found 
                 (re-search-forward emaxima-any-cell-begin-regexp 
@@ -626,7 +627,7 @@ without asking."
         files parts prompt
         tmp-buffer tmp-alist file-buffer)
     (if (not file)
-        ;; If file has not been specifed, prompt
+        ;; If file has not been specified, prompt
         (progn
               ;; Get default file from cell label, if any
               (save-excursion
@@ -1016,7 +1017,7 @@ then the substring preceding the `...' is used with try-completion on ALIST.
 An exact match is required if optional EXACT is t.
 If text is just `...' and alist is length 1, then the car of its single element
 is returned.
-Oherwise nil is returned."
+Otherwise nil is returned."
   (let (name try-name)
     (if (not (string-match "\\(\\.\\.\\.$\\)" text))
         (setq name text) ; don't do completion on full names
@@ -1154,7 +1155,7 @@ Return nil if no name or error in name."
     found))
 
 (defun emaxima-reference-p ()
-  "Return t if cell contains a cell reference, else retrun nil."
+  "Return t if cell contains a cell reference, else return nil."
   (save-excursion
     (goto-char (emaxima-cell-start))
     (if (re-search-forward "^ *\t*<[^:].*:[^>].*>$" (emaxima-cell-end) t)
@@ -1360,7 +1361,7 @@ Return nil if no name or error in name."
         (cell (emaxima-get-cell-contents)))
     (goto-char (emaxima-cell-end))
     (forward-line 1)
-    (insert "\\maximaoutput\n\n")
+    (insert "\\maximaoutput\n")
     (while (or
             (string-match "[$;]" cell)
             (eq (string-match "[ \n]*:lisp" cell) 0))
@@ -1401,7 +1402,7 @@ Return nil if no name or error in name."
           (cell (emaxima-get-cell-contents)))
       (goto-char (emaxima-cell-end))
       (forward-line 1)
-      (insert "\\maximaoutput\n\n")
+      (insert "\\maximaoutput\n")
       (while (or
               (string-match "[$;]" cell)
               (eq (string-match "[ \n]*:lisp" cell) 0))
@@ -1418,7 +1419,6 @@ Return nil if no name or error in name."
         (insert (substring cell 0 end))
         (unless (string= "\n" (substring cell (- end 1) end))
           (insert "\n"))
-        (insert "\n")
         (insert (maxima-last-output))
         (setq cell (substring cell end))))))
 
