@@ -1,15 +1,15 @@
 ;; Copyright (C) 2001, 2002, 2003, 2004 Jesper Harder
 ;; Copyright (C) 2007, 2008 Yasuaki Honda
+;; Copyright (C) 2020, 2021 Leo Butler
 ;;
 ;; Plotting support section of this file is the copy of the same
 ;; section of wxmathml.lisp with very small modification. The file
 ;; wxmathml.lisp is a part of the distribution of wxMaxima.
 
-;; Author: Jesper Harder <harder@ifa.au.dk>
 ;; Created: 14 Nov 2001
-;; Version: 1.0b
+;; Version: See version.texi
 ;; Keywords: maxima
-;; $Id: imaxima.lisp,v 1.8 2011-01-05 22:49:31 riotorto Exp $
+;; Time-stamp: <2021-05-03 Leo Butler (dev)>
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
@@ -41,67 +41,26 @@
 ;;; issue.
 ;;; by yasuaki honda
 
-;;;
-;;; There is a report that some Linux provides Maxima with GCL
-;;; which does not support handler-bind. The macro
-;;; style-warning-suppressor
-;;; is introduced to check if handler-bind is defined or not.
-;;;
-;;; by yasuaki honda 2007/06/10
-;;;
-
 (in-package :maxima)
 
-(defvar *windows-OS* (string= *autoconf-win32* "true"))
+(setq $maxima_frontend "imaxima")
+(setq $maxima_frontend_version *autoconf-version*)
+
+(defvar *windows-OS* (string= *autoconf-windows* "true"))
 (defmvar $wxplot_size '((mlist simp) 400 250))
 (defmvar $wxplot_old_gnuplot nil)
 (defvar *image-counter* 0)
 
-
-;;; Following function wx-gnuplot-installed-p and the macro
-;;; wx-gnuplot-installation-check should be in plotting section
-;;; later in this file. However, because they must be in the
-;;; real toplevel, they are moved here.
-;;; yasuaki honda
-(defun wx-gnuplot-installed-p ()
-  #+gcl
-  (cond ((member :linux *features*)
-	 (let* ((tmp-stream (open "| which gnuplot" :direction :input))
-		(result (read-line tmp-stream nil :eof)))
-	   (if (eql result :eof) nil t)))
-	((and (member :mingw32 *features*)
-	      (probe-file "c:\\Windows\\System32\\where.exe"))
-	 (let* ((tmp-stream (open "| where wgnuplot" :direction :input))
-		(result (read-line tmp-stream nil :eof)))
-	   (if (eql result :eof) nil t)))
-	(t t))
-  #-gcl
+(defun wx-gnuplot-installation-check ()
   ;; The function check-gnuplot-process is defined in
   ;; maxima/src/plot.lisp since at least 5.12.0.
-  (handler-case (progn (check-gnuplot-process) t)
-		(error () nil)))
-
-(defun wx-gnuplot-installation-check ()
-  (if (not (wx-gnuplot-installed-p))
+  (flet ((wx-gnuplot-installed-p ()
+	   (ignore-errors (check-gnuplot-process) t)))
+    (unless (wx-gnuplot-installed-p)
       (merror (format t "Gnuplot error: Gnuplot is not installed,
-nor Gnuplot is not recognized by maxima"))))
+nor Gnuplot is not recognized by maxima")))))
 
-(defmacro style-warning-suppressor (&rest body)
-  (if (member :clisp *features*)
-      (setq body (cons
-		  '(let ((scr (find-symbol "*SUPPRESS-CHECK-REDEFINITION*" :CUSTOM)))
-		     (if scr (set scr t)))
-		  body)))
-  (if (macro-function 'handler-bind)
-      `(handler-bind ((style-warning #'muffle-warning))
-		     ,@body)
-    `(progn ,@body)))
-
-(style-warning-suppressor
-
-(declare-top
-	 (special lop rop $gcprint $inchar *autoconf-version*)
-	 (*expr tex-lbp tex-rbp))
+(declare-top (special lop rop $gcprint $inchar *autoconf-version*))
 
 ;;;
 ;;; Very unfortunately, the following code does not work in
@@ -119,10 +78,6 @@ nor Gnuplot is not recognized by maxima"))))
 
 (defun diff-symbol () '$d)
 
-(defun memq (elem seq)
-  #+(or cmu scl) (declare (inline member))
-  (member elem seq :test #'eq))
-
 (defun main-prompt ()
   (format () (concatenate 'string (string (code-char 3)) "(~A~D) " (string (code-char 4)))
     (stripdollar (print-case-sensitive $inchar)) $linenum))
@@ -201,6 +156,16 @@ nor Gnuplot is not recognized by maxima"))))
   (setq str (unquote-%-internal str #\#))
   str)
 
+(defun verb-quote (str)
+  (let ((var "") (charlist
+		  '((#\Newline . "| \\\\ \\verb| "))))
+    (dotimes (i (length str))
+      (let ((chari (elt str i)))
+	(setq var (concatenate 'string var
+			       (or (cdr (assoc chari charlist :test #'eql))
+				   (string chari))))))
+  var))
+
 (defun tex-string (x)
   (let ((sym-name
 	 (if (symbolp x)
@@ -208,23 +173,12 @@ nor Gnuplot is not recognized by maxima"))))
 	   x)))
     (cond ((equal sym-name "") "")
 	  ((eql (elt sym-name 0) #\\) sym-name)
-	  ((memq (elt sym-name 0) '(#\$ #\&))
+	  ((member (elt sym-name 0) '(#\$ #\&))
 	   (setq sym-name (unquote-% (subseq sym-name 1)))
 	   (concatenate 'string "\\verb|   " (verb-quote sym-name) "|"))
 	  (t (setq sym-name (unquote-% sym-name))
 	     (concatenate 'string "\\verb|" (verb-quote sym-name) "|")))))
 
-(defun verb-quote (str)
-  (let ((var "") (charlist
-		  '((#\Newline . "| \\\\ \\verb| "))))
-    (dotimes (i (length str))
-      (let ((chari (elt str i)))
-	(setq var (concatenate 'string var 
-			       (or (cdr (assoc chari charlist :test #'eql))
-				   (string chari))))))
-  var))
-
-
 (defun tex-char (x)
   (if (eql x #\|) "\\verb/|/"
     (concatenate 'string "\\verb|" (string x) "|")))
@@ -250,7 +204,7 @@ nor Gnuplot is not recognized by maxima"))))
 (defun tex-stripdollar (sym)
   (or (symbolp sym) (return-from tex-stripdollar sym))
   (let* ((name (print-case-sensitive sym))
-      (pname (if (memq (elt name 0) '(#\$ #\&)) (subseq name 1) name))
+      (pname (if (member (elt name 0) '(#\$ #\&)) (subseq name 1) name))
       (l (length pname)))
     (cond
      ((eql l 1) (myquote pname))
@@ -507,6 +461,12 @@ nor Gnuplot is not recognized by maxima"))))
 
 ; jh: verb & mbox
 
+(defun input-label-p (label)
+  (if (symbolp label)
+      (let ((name (symbol-name label)))
+	(and (> (length name) 3)
+	     (string= "$%I" (subseq name 0 3))))))
+
 (defun latex (x)
 ;  (princ x)  ;; uncomment to debug.
   (if (and (listp x) (car x) (listp (car x)) (caar x)
@@ -518,7 +478,6 @@ nor Gnuplot is not recognized by maxima"))))
 	(declare (special $display2d))
 	(displa x)
 	(return-from latex)))
-  (fresh-line)
   (mapc #'princ
 	(if (and (listp x) (cdr x) (stringp (cadr x))
 		 (equal (string-right-trim '(#\Space) (cadr x)) "Is"))
@@ -527,12 +486,6 @@ nor Gnuplot is not recognized by maxima"))))
 	  (tex x (list (string (code-char 2)))
 	         (list (string (code-char 5))) 'mparen 'mparen))))
 
-(defun input-label-p (label)
-  (if (symbolp label)
-      (let ((name (symbol-name label)))
-	(and (> (length name) 3)
-	     (string= "$%I" (subseq name 0 3))))))
-
 (let ((old-displa (symbol-function 'displa)))
   (defun displa (form)
     (if (eq $display2d '$imaxima)
@@ -551,8 +504,7 @@ nor Gnuplot is not recognized by maxima"))))
 		      ((memq answer '($unknown $uk)) '$unknown)))
     (setq answer (retrieve
 		  `((mtext) "Is  " ,object 
-		    ,(if (member (getcharn property 1)
-				 '(#\a #\e #\i #\o #\u)
+		    ,(if (member (get-first-char property) '(#\a #\e #\i #\o #\u)
 				 :test #'char-equal)
 			 '"  an "
 			 '"  a ")
@@ -567,159 +519,113 @@ nor Gnuplot is not recognized by maxima"))))
 ;;
 ;; Plotting support
 ;;
+
+(defvar $imaxima_tmp_subdir nil "Bound to the value of `imaxima-tmp-subdir' in `imaxima-mode'.")
+(defun imaxima-apply (fun args)
+  "Binds `*maxima-tempdir*' to `$imaxima_tmp_subdir' before `apply'."
+  (declare (special *maxima-tempdir* $imaxima_tmp_subdir))
+  (let ((*maxima-tempdir* $imaxima_tmp_subdir))
+    (apply fun args)))
 		       
 (defun wxxml-tag (x l r)
   (let ((name (cadr x))
 	(tag (caddr x)))
     (append l (list (format nil "<~a>~a</~a>" tag name tag)) r)))
 
-
-(defun wxplot-filename (&optional (suff t) &aux filename)
+(defun wxplot-filename (&optional (suff t))
+  (declare (special *image-counter*))
   (incf *image-counter*)
-  (setq filename
-	(plot-temp-file (if suff
-			    (format nil "maxout_~d.eps" *image-counter*)
-			  (format nil "maxout_~d" *image-counter*))))
-  (if (probe-file filename)
-      (delete-file filename))
-  filename)
+  (let* ((name (format nil "maxout_~d~a" *image-counter* (if suff ".eps" "")))
+	 (filename (imaxima-apply #'plot-temp-file (list name))))
+    (if (probe-file filename)
+	(delete-file filename))
+    filename))
 
-(defun $wxplot_preamble ()
-  (let ((frmt (if $wxplot_old_gnuplot
-		  "set terminal postscript picsize ~d ~d; set zeroaxis;"
-		  "set terminal postscript size ~d,~d; set zeroaxis;")))
-    (format nil frmt
-	    ($first $wxplot_size)
-	    ($second $wxplot_size))))
+(defvar $wx_data_file "data_~a.gnuplot" "A FORMAT string that takes exactly one argument, *image-counter*; or a MAXIMA function.")
+(defvar $wx_gnuplot_file "maxout_~a.gnuplot" "A FORMAT string that takes exactly one argument, *image-counter*; or a MAXIMA function.")
+
+(defun wxplot-data+maxout ()
+  (declare (special *image-counter* $wx_data_file $wx_gnuplot_file))
+  (let ((datafile (if (stringp $wx_data_file) (format nil $wx_data_file *image-counter*) (mfuncall $wx_data_file *image-counter*)))
+	(gnpltfile (if (stringp $wx_data_file) (format nil $wx_gnuplot_file *image-counter*) (mfuncall $wx_gnuplot_file *image-counter*))))
+    (cons datafile gnpltfile)))
 
 (defun $range (i j)
   (let ((x (gensym)))
     (mfuncall '$makelist x x i j)))
 
-(defun $wxplot2d (&rest args)
+(defun maybe-load-package-for (wx-fun)
+  (let ((fun ($get wx-fun '$function))
+	(pkg ($get wx-fun '$load_package)))
+    (if (and pkg (not (fboundp fun))) ($load pkg))))
+
+(defun wxplot (wx-fun &rest args)
   ;; if gnuplot is not installed, this will terminate the
   ;; further execution.
   (wx-gnuplot-installation-check)
-  (let ((preamble ($wxplot_preamble))
-	(system-preamble (get-plot-option-string '$gnuplot_preamble 2))
-	(filename (wxplot-filename)))
-    (if (length system-preamble)
-	(setq preamble (format nil "~a; ~a" preamble system-preamble)))
-    (dolist (arg args)
-      (if (and (listp arg) (eql (cadr arg) '$gnuplot_preamble))
-	  (setq preamble (format nil "~a; ~a"
-				 preamble (caddr arg)))))
-    (apply #'$plot2d `(,@args
-		       ((mlist simp) $plot_format $gnuplot)
-;;		       ((mlist simp) $gnuplot_preamble ,preamble)
-		       ((mlist simp) $gnuplot_term $ps)
-		       ((mlist simp) $gnuplot_out_file ,filename)))
-    ($ldisp `((wxxmltag simp) ,filename "img")))
-  "")
+  (let ((filename (wxplot-filename))
+	(data+maxout (wxplot-data+maxout))
+	(fun ($get wx-fun '$function)))
+    (maybe-load-package-for wx-fun)
+    (imaxima-apply fun
+		   `(,@args
+		     ((mlist simp) $plot_format $gnuplot)
+		     ((mlist simp) $gnuplot_term $ps)
+		     ((mlist simp) $ps_file ,filename)
+		     ((mlist simp) $gnuplot_script_file ,(cdr data+maxout))))
+    ($ldisp `((wxxmltag simp) ,filename "img"))
+    fun))
 
-(defun $wxplot3d (&rest args)
-  ;; if gnuplot is not installed, this will terminate the
-  ;; further execution.
-  (wx-gnuplot-installation-check)
-  (let ((preamble ($wxplot_preamble))
-	(system-preamble (get-plot-option-string '$gnuplot_preamble 2))
-	(filename (wxplot-filename)))
-    (if (length system-preamble)
-	(setq preamble (format nil "~a; ~a" preamble system-preamble)))
-    (dolist (arg args)
-      (if (and (listp arg) (eql (cadr arg) '$gnuplot_preamble))
-	  (setq preamble (format nil "~a; ~a"
-				 preamble (caddr arg)))))
-    (apply #'$plot3d `(,@args
-		       ((mlist simp) $plot_format $gnuplot)
-;;		       ((mlist simp) $gnuplot_preamble ,preamble)
-		       ((mlist simp) $gnuplot_term $ps)
-		       ((mlist simp) $gnuplot_out_file ,filename)))
-    ($ldisp `((wxxmltag simp) ,filename "img")))
-  "")
-
-(defun $wxdraw2d (&rest args)
-  (apply #'$wxdraw
-	 (list (cons '($gr2d) args))))
-
-
-(defun $wxdraw3d (&rest args)
-  (apply #'$wxdraw
-	 (list (cons '($gr3d) args))))
-
-(defun $wxdraw (&rest args)
+(defun wxdraw (wx-fun &rest args)
+  (declare (special *image-counter*))
   ;; if gnuplot is not installed, this will terminate the
   ;; further execution.
   (wx-gnuplot-installation-check)
   (let* ((filename (wxplot-filename nil))
-	 (*windows-OS* t)
-	 res)
-    (if (not (fboundp '$draw))
-	($load '$draw))
-    ;; Usually the following is used.
-    ;;    (setq res (apply #'$draw
-    ;; However, CMUCL warns that function $draw is not defined.
-    ;; To suppress this warning, symbol-function is used to make
-    ;; clear that the runtime definition is used rather than 
-    ;; read time.
-    (setq res (apply (symbol-function '$draw)
-		     (append
-		      `(
-			((mequal simp) $terminal $eps_color)
-                        ((mequal simp) $dimensions
-                                       ((mlist simp)
-                                        ;; convert points to 1/100 of cm
-                                        ,(* 3.53 ($first $wxplot_size))
-                                        ,(* 3.53 ($second $wxplot_size))))
-			((mequal simp) $file_name ,filename))
-		      args)))
-    ($ldisp `((wxxmltag simp) ,(format nil "~a.eps" filename) "img"))
-    res))
+	 (datafile (format nil "data_~a.gnuplot" *image-counter*))
+	 (gnpltfile (format nil "maxout_~a.gnuplot" *image-counter*))
+	 (fun ($get wx-fun '$function))
+	 (*windows-OS* t))
+    (maybe-load-package-for wx-fun)
+    (prog1
+	(imaxima-apply fun
+		       (append
+			`(((mequal simp) $terminal $eps_color)
+			  ((mequal simp) $dimensions
+			   ((mlist simp)
+			    ;; convert points to 1/100 of cm
+			    ,(* 3.53 ($first $wxplot_size))
+			    ,(* 3.53 ($second $wxplot_size))))
+			  ((mequal simp) $file_name ,filename)
+			  ((mequal simp) $data_file_name ,datafile)
+			  ((mequal simp) $gnuplot_file_name ,gnpltfile))
+			args))
+      ($ldisp `((wxxmltag simp) ,(format nil "~a.eps" filename) "img")))))
 
-(defun $wximplicit_plot (&rest args)
-  ;; if gnuplot is not installed, this will terminate the
-  ;; further execution.
-  (wx-gnuplot-installation-check)
-  (let ((preamble ($wxplot_preamble))
-	(system-preamble (get-plot-option-string '$gnuplot_preamble 2))
-	(filename (wxplot-filename)))
-    (if (not (fboundp '$implicit_plot))
-	($load '$implicit_plot))
-    (if (length system-preamble)
-	(setq preamble (format nil "~a; ~a" preamble system-preamble)))
-    (dolist (arg args)
-      (if (and (listp arg) (eql (cadr arg) '$gnuplot_preamble))
-	  (setq preamble (format nil "~a; ~a"
-				 preamble (caddr arg)))))
-    (apply (symbol-function '$implicit_plot)
-	   `(,@args
-	     ((mlist simp) $plot_format $gnuplot)
-;;           ((mlist simp) $gnuplot_preamble ,preamble)
-	     ((mlist simp) $gnuplot_term $ps)
-	     ((mlist simp) $gnuplot_out_file ,filename)))
-    ($ldisp `((wxxmltag simp) ,filename "img")))
-  "")
+(defmacro wx-def-plot/draw (fun pkg parent &optional init  &rest body)
+  (let ((wx-fun (intern (format nil "$WX~a" (stripdollar fun)))))
+    `(progn
+       ,init
+       ($put ',wx-fun ',pkg '$load_package)
+       ($put ',wx-fun ',fun '$function)
+       (defun ,wx-fun (&rest args)
+	 ,body
+	 (imaxima-apply ',parent (cons ',wx-fun args))))))
+
+(wx-def-plot/draw $draw 	 $draw 		wxdraw)
+(wx-def-plot/draw $draw2d 	 $draw 		wxdraw)
+(wx-def-plot/draw $draw3d 	 $draw 		wxdraw)
+(wx-def-plot/draw $plot2d 	 nil   		wxplot)
+(wx-def-plot/draw $plot3d 	 nil   		wxplot)
+(wx-def-plot/draw $implicit_plot $implicit_plot wxplot)
+(wx-def-plot/draw $contour_plot  nil 		wxplot)
+(wx-def-plot/draw $julia 	 $dynamics 	wxplot)
+(wx-def-plot/draw $mandelbrot    $dynamics 	wxplot)
+
+;; We could load drawdf package, because we want to overwrite wxdrawdf.
+;; However, we do not need to, because wxdrawdf is a wrapper for wxdraw.
+;; The following will load drawdf, then overwrite wxdrawdf with our own:
+;; (wx-def-plot/draw $drawdf 	 $drawdf	wxdraw ($load '$drawdf))
 
 
-(defun $wxcontour_plot (&rest args)
-  ;; if gnuplot is not installed, this will terminate the
-  ;; further execution.
-  (wx-gnuplot-installation-check)
-  (let ((preamble ($wxplot_preamble))
-	(system-preamble (get-plot-option-string '$gnuplot_preamble 2))
-	(filename (wxplot-filename)))
-    (if (length system-preamble)
-	(setq preamble (format nil "~a; ~a" preamble system-preamble)))
-    (dolist (arg args)
-      (if (and (listp arg) (eql (cadr arg) '$gnuplot_preamble))
-	  (setq preamble (format nil "~a; ~a" preamble (caddr arg)))))
-    (apply #'$contour_plot `(,@args
-			     ((mlist simp) $plot_format $gnuplot)
-;;			     ((mlist simp) $gnuplot_preamble ,preamble)
-			     ((mlist simp) $gnuplot_term $ps)
-			     ((mlist simp) $gnuplot_out_file ,filename)))
-
-    ($ldisp `((wxxmltag simp) ,filename "img")))
-  "")
-
-) ;; This paran closes style-warning-suppressor.
+;; end of imaxima.lisp
