@@ -1,6 +1,5 @@
-# -*-mode: tcl; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*-
-#
-#       $Id: OpenMath.tcl,v 1.17 2011/03/15 01:13:22 villate Exp $
+#     OpenMath.tcl
+#     Time-stamp: "2021-03-28 17:36:15 villate"
 #
 proc genSample { x n } {
     set sample $x
@@ -170,7 +169,7 @@ proc omPanel { w args } {
 	    }
 	}
     } else {
-	#mike slate the old histroy list for demolition
+	#mike slate the old history list for demolition
 	button $win.loclabel -text " Url:" \
 	    -command "OpenMathOpenUrl \[$win.location get\] -commandpanel  $win"
 	setHelp $win.loclabel [mc {Fetch the URL or FILE indicated in the entry box. \
@@ -570,7 +569,7 @@ proc doInsertp { tags } {
 #----------------------------------------------------------------
 #
 proc doInvoke { w index } {
-    global evalPrograms MathServer
+    global evalPrograms
     set tags [$w tag names $index]
 
     $w tag delete sel
@@ -583,8 +582,6 @@ proc doInvoke { w index } {
     set res [resolveURL $program [oget $w baseprogram]]
     # puts "program=$program,baseprogram[oget $w baseprogram],res=$res"
 
-    set MathServer "[assoc server $res [lindex $MathServer 0]] \
-	   [assoc port $res [lindex $MathServer 1]]"
     set this [thisRange $w  program:$program $index]
     # puts "this=$this"
 
@@ -945,7 +942,7 @@ proc markForProgram { w args } {
 	    $w insert tmp RESULT {Tresult Tmodified}
 	    $w insert tmp " "  {plain}
 	} else {
-	    apply $w tag add Tmodified $nextResult
+	    mxapply $w tag add Tmodified $nextResult
 	}
 
     }
