@@ -113,6 +113,18 @@
       (graph-size gr)
       (digraph-size gr)))
 
+(defmfun $get_positions (gr)
+  (require-graph-or-digraph 'get_positions 1 gr)
+  (if (graph-p gr)
+      (graph-vertex-positions gr)
+      (digraph-vertex-positions gr)))
+
+(defmfun $set_positions (pos gr)
+  (require-graph-or-digraph 'set_positions 2 gr)
+  (if (graph-p gr)
+      (setf (graph-vertex-positions gr) pos)
+      (setf (digraph-vertex-positions gr) pos)))
+
 (defmfun $copy_graph (gr)
   (require-graph-or-digraph 'copy_graph 1 gr)
   (if (graph-p gr)
@@ -139,18 +151,6 @@
         ($set_positions ($get_positions gr) g)
 	g) ))
 
-(defmfun $get_positions (gr)
-  (require-graph-or-digraph 'get_positions 1 gr)
-  (if (graph-p gr)
-      (graph-vertex-positions gr)
-      (digraph-vertex-positions gr)))
-
-(defmfun $set_positions (pos gr)
-  (require-graph-or-digraph 'set_positions 2 gr)
-  (if (graph-p gr)
-      (setf (graph-vertex-positions gr) pos)
-      (setf (digraph-vertex-positions gr) pos)))
-
 (defmfun $new_graph ()
   (make-graph))
 
@@ -409,7 +409,7 @@
 
 (defun require-medge (m ar e)
   (cond
-    ((not (and ($listp e) (eq 2 ($length e))))
+    ((not (and ($listp e) (eql 2 ($length e))))
      ($error "Argument" ar "to" m "is not an edge (0)."))
     (t (let ((u ($first e)) (v ($second e)))
 	 (unless (and (integerp u) (integerp v))
@@ -689,7 +689,7 @@
     gr))
 
 (defmfun $empty_digraph (n)
-  (let ((gr (make-digraph)) (pos))
+  (let ((gr (make-digraph)))
     (dotimes (i n)
       (add-vertex i gr))
     gr))
@@ -953,6 +953,7 @@
     g))
 
 (defmfun $random_graph1 (n m)
+  #+sbcl (declare (notinline $random_graph1))
   (unless (integerp n)
     ($error "Argument 1 to random_graph is not an integer"))
   (unless (integerp m)
@@ -1389,10 +1390,6 @@
 ;;; 2-connectivity
 ;;;
 
-(defmfun $is_biconnected (gr)
-  (require-graph 'is_biconnected 1 gr)
-  (eq ($length ($biconnected_components gr)) 1))
-
 (defmfun $biconnected_components (gr)
   (require-graph 'biconnected_components 1 gr)
   (if (= 0 (graph-order gr))
@@ -1406,6 +1403,10 @@
 	      (setq bicomp ($append bicomp (bicomponents ($first c) gr)))))
 	bicomp)))
 
+(defmfun $is_biconnected (gr)
+  (require-graph 'is_biconnected 1 gr)
+  (eql ($length ($biconnected_components gr)) 1))
+
 (defvar *dfs-bicomp-depth* 0)
 (defvar *dfs-bicomp-num* ())
 (defvar *dfs-bicomp-low-pt* ())
@@ -1470,10 +1471,6 @@
 (defvar *scon-vrt* nil)
 (defvar *scon-depth* 0)
 
-(defmfun $is_sconnected (gr)
-  (require-digraph 'strong_components 1 gr)
-  (eq ($length ($strong_components gr)) 1))
-
 (defmfun $strong_components (gr)
   (require-digraph 'strong_components 1 gr)
   (if (= 0 (digraph-order gr))
@@ -1492,6 +1489,10 @@
 	      (setq *scon-comp* ()))
 	`((mlist simp) ,@res))))
 
+(defmfun $is_sconnected (gr)
+  (require-digraph 'strong_components 1 gr)
+  (eql ($length ($strong_components gr)) 1))
+
 (defun dfs-strong-components (gr v)
   (incf *scon-depth*)
   (setf (gethash v *scon-dfn*) *scon-depth*)
@@ -1634,23 +1635,15 @@
     (do ()
 	((or (= 0 (hash-table-count active)) (gethash v visited)))
       (let ((next (make-hash-table)))
-	(with-hash-table-iterator (next-vertex active)
-	  (loop
-	     (multiple-value-bind (more w value)
-		 (next-vertex)
-	       (declare (ignore value))
-	       (unless more (return nil))
-	       (setf (gethash w visited) t)
-	       (dolist (x (neighbors w g))
-		 (unless (or (gethash x active) (gethash x visited) (gethash x next))
-		   (setf (gethash x previous) w)
-		   (setf (gethash x next) t))
-		 (when (= v x)
-		   (setq more nil)))
-	       (unless more (return nil)))))
-	(setq active next)))
+        (loop for w being the hash-keys of active do
+             (setf (gethash w visited) t)
+             (dolist (x (neighbors w g))
+               (unless (or (gethash x active) (gethash x visited) (gethash x next))
+                 (setf (gethash x previous) w)
+                 (setf (gethash x next) t))))
+        (setq active next)))
     (if (gethash v visited)
-	(let ((path `(,v)))
+	(let ((path (list v)))
 	  (do ((x v))
 	      ((= x u))
 	    (setq x (gethash x previous))
@@ -1831,17 +1824,6 @@
       (remove-vertex v h)))
   `((mlist simp) ,@(sort *maximum-clique* #'<)))
 
-(defmfun $max_independent_set (gr)
-  (require-graph 'max_independent_set 1 gr)
-  (if ($is_bipartite gr)
-      (let ((mis)
-	    (vc (cdr ($min_vertex_cover gr))))
-	(loop for v in (vertices gr) do
-	     (unless (member v vc)
-	       (setq mis (cons v mis))))
-	`((mlist simp) ,@mis))
-      ($max_clique ($complement_graph gr))))
-
 (defmfun $min_vertex_cover (gr)
   (require-graph 'min_vertex_cover 1 gr)
   (let ((bipart ($bipartition gr)))
@@ -1854,6 +1836,17 @@
 	  `((mlist simp) ,@vc))
 	(maximum-matching-bipartite gr (cadr bipart) (caddr bipart) t))))
 
+(defmfun $max_independent_set (gr)
+  (require-graph 'max_independent_set 1 gr)
+  (if ($is_bipartite gr)
+      (let ((mis)
+	    (vc (cdr ($min_vertex_cover gr))))
+	(loop for v in (vertices gr) do
+	     (unless (member v vc)
+	       (setq mis (cons v mis))))
+	`((mlist simp) ,@mis))
+      ($max_clique ($complement_graph gr))))
+
 (defun extend-clique (clique neigh coloring gr)
   (if (= (length neigh) 0)
       ;; did we get to a maximal clique
