@@ -689,7 +689,7 @@ One extra decimal digit in actual representation for rounding purposes.")
 
 (defun extreme-float-values (x)
   ;; BLECHH, I HATE ENUMERATING CASES. IS THERE A BETTER WAY ??
-  (case (type-of x)
+  (typecase x ;gcl returns an atomic list type with type-of
     (short-float (values most-negative-short-float most-positive-short-float))
     (single-float (values most-negative-single-float most-positive-single-float))
     (double-float (values most-negative-double-float most-positive-double-float))
@@ -707,7 +707,9 @@ One extra decimal digit in actual representation for rounding purposes.")
   (if (float-inf-p x)
     (merror (intl:gettext "bfloat: attempted conversion of floating-point infinity.~%")))
   (unless $float2bf
-    (mtell (intl:gettext "bfloat: converting float ~S to bigfloat.~%") x))
+    (let ((p (float-precision x)))
+      (if (< fpprec p)
+        (mtell (intl:gettext "bfloat: converting float ~S to bigfloat.~%") x))))
 
   ;; Need to check for zero because different lisps return different
   ;; values for integer-decode-float of a 0.  In particular CMUCL
@@ -1160,7 +1162,7 @@ One extra decimal digit in actual representation for rounding purposes.")
 ;; bigfloat tag.
 ;;
 ;; See
-;; https://sourceforge.net/tracker/?func=detail&atid=104933&aid=2910437&group_id=4933
+;; https://sourceforge.net/p/maxima/bugs/1842/
 ;; for an explanation.
 (let ((table (make-hash-table)))
   (defun fpe ()
@@ -2474,8 +2476,8 @@ One extra decimal digit in actual representation for rounding purposes.")
 		    (bigfloatp result))))))
 	(let ((fp-x (cdr (bigfloatp x))))
 	  (cond ((onep1 x)
-		 ;; Special case for log(1).  See Bug 3381301:
-		 ;; https://sourceforge.net/tracker/?func=detail&aid=3381301&group_id=4933&atid=104933
+		 ;; Special case for log(1).  See:
+		 ;; https://sourceforge.net/p/maxima/bugs/2240/
 		 (bcons (intofp 0)))
 		((fplessp fp-x (intofp 0))
 		 ;; ??? Do we want to return an exact %i*%pi or a float
