@@ -15,13 +15,17 @@
 (load-macsyma-macros defcal mopers)
 
 (defmvar *alphabet* (list #\_ #\%))
+(defmvar *whitespace-chars*
+         '(#\tab #\space #\linefeed #\return #\page #\newline
+           #+(or (and unicode (not lispworks))
+                 sb-unicode openmcl-unicode-strings) #\no-break_space))
 
-(defmfun alphabetp (n)
+(defun alphabetp (n)
   (and (characterp n)
-       (or (alpha-char-p n)
+       (or (alpha-char-p n) #+gcl(>= (char-code n) 128)
 	   (member n *alphabet*))))
 
-(defmfun ascii-numberp (num)
+(defun ascii-numberp (num)
   (and (characterp num) (char<= num #\9) (char>= num #\0)))
 
 (defvar *parse-window* nil)
@@ -33,6 +37,11 @@
 (defvar *mread-eof-obj* ()    "Bound by `mread' for use by `mread-raw'")
 (defvar *current-line-info* nil)
 
+(defvar *parse-string-input-stream*             ;; reference to the input stream 
+  (let ((stream (make-string-input-stream ""))) ;;   used by parse-string
+    (close stream)                              ;;   in share/stringroc/eval_string.lisp
+    stream ))                                   ;; (see also add-lineinfo below)
+
 (defmvar $report_synerr_line t "If T, report line number where syntax error occurs; otherwise, report FILE-POSITION of error.")
 (defmvar $report_synerr_info t "If T, report the syntax error details from all sources; otherwise, only report details from standard-input.")
 
@@ -90,6 +99,7 @@
 	       (format t "~%~{~c~}~%~vt^" some (- (length some) 2))
 	       (read-line *parse-stream* nil nil))))
       (terpri)
+      (finish-output)
       (throw-macsyma-top))))
 
 (defun tyi-parse-int (stream eof)
@@ -123,7 +133,7 @@
 
 (defun gobble-whitespace ()
   (do ((ch (parse-tyipeek) (parse-tyipeek)))
-      ((not (member ch '(#\tab #\space #\linefeed #\return #\page #\newline))))
+      ((not (member ch *whitespace-chars*)))
     (parse-tyi)))
 
 (defun read-command-token (obj)
@@ -155,7 +165,7 @@
 ;; characters, since if you do
 ;; PREFIX("ABCDEFGH");
 ;; then ABCDEFGA should read as a symbol.
-;; 99% of the time we dont have to unparse-tyi, and so there will
+;; 99% of the time we don't have to unparse-tyi, and so there will
 ;; be no consing...
 
 (defun parse-tyi ()
@@ -222,8 +232,7 @@
 		             ;; when grad is defined as a prefix operator.
 		             ;; See bug report ID: 2970792.
 		             (or (not (alphabetp (cadr (exploden (cadr (cadr lis))))))
-		                 (member (parse-tyipeek)
-		                         '(#\tab #\space #\linefeed #\return #\page #\newline)))
+		                 (member (parse-tyipeek) *whitespace-chars*))
 		             (cadr (cadr lis)))))
 	         (t
 		  (let ((res   (and (eql (car (cadr lis)) 'ans)
@@ -324,6 +333,7 @@
 			 (map nil #'princ x))
 		 (reverse numlist))
 	    (terpri)
+	    (finish-output)
 	    (unless (equalp true fast)
 	      (incf failures)
 	      (format t "NUM:  ~A~%  TRUE: ~S~%  FAST: ~S~%"
@@ -558,7 +568,8 @@
 	(setq c (parse-tyipeek))
 	(parse-tyi)
 	(cond ((= depth 0) (return t)))
-	(cond ((and (numberp c) (< c 0))(error (intl:gettext "parser: end of file in comment.")))
+	(cond ((eql c *parse-stream-eof*)
+	       (error (intl:gettext "parser: end of file in comment.")))
 	      ((char= c #\*)
 	       (cond ((char= (parse-tyipeek) #\/)
 		      (decf depth)
@@ -574,7 +585,7 @@
 
 (defun scan-number-rest (data)
   (let ((c (caar data)))
-    (cond ((member c '(#\.))
+    (cond ((char= c #\.)
 	   ;; We found a dot
 	   (scan-number-after-dot data))
 	  ((member c '(#\E #\e #\F #\f #\B #\b #\D #\d #\S #\s #\L #\l #+cmu #\W #+cmu #\w))
@@ -667,20 +678,20 @@
 (defmacro def-nud ((op . lbp-rbp) bvl . body)
   (let (( lbp (nth 0 lbp-rbp))
 	( rbp (nth 1 lbp-rbp)))
-    `(progn 'compile 	  ,(make-parser-fun-def op 'nud bvl body)
+    `(progn ,(make-parser-fun-def op 'nud bvl body)
 	    (set-lbp-and-rbp ',op ',lbp ',rbp))))
 
 (defun set-lbp-and-rbp (op lbp rbp)
   (cond ((not (consp op))
 	 (let ((existing-lbp (get op 'lbp))
 	       (existing-rbp (get op 'rbp)))
-	   (cond ((not lbp) ;; ignore ommitted arg
+	   (cond ((not lbp) ;; ignore omitted arg
 		  )
 		 ((not existing-lbp)
 		  (putprop op lbp 'lbp))
 		 ((not (equal existing-lbp lbp))
 		  (maxima-error "Incompatible LBP's defined for this operator ~a" op)))
-	   (cond ((not rbp) ;; ignore ommitted arg
+	   (cond ((not rbp) ;; ignore omitted arg
 		  )
 		 ((not existing-rbp)
 		  (putprop op rbp 'rbp))
@@ -706,8 +717,7 @@
 (defmacro def-led((op . lbp-rbp) bvl . body)
   (let (( lbp (nth 0 lbp-rbp))
 	( rbp (nth 1 lbp-rbp)))
-    `(progn 'compile
-	    ,(make-parser-fun-def  op 'led bvl body)
+    `(progn ,(make-parser-fun-def  op 'led bvl body)
 	    (set-lbp-and-rbp ',op ',lbp ',rbp))))
 
 (defmacro def-collisions (op &rest alist)
@@ -715,7 +725,7 @@
 		   (lis  alist (cdr lis))
 		   (nl ()    (cons (cons (caar lis) i) nl)))
 		  ((null lis) nl))))
-    `(progn 'compile
+    `(progn
        (defprop ,op ,(let nil
 			  (copy-tree keys )) keys)
        ,@(mapcar #'(lambda (data)
@@ -759,7 +769,7 @@
 ;;; (LBP <op>)		 - reads an operator's Left Binding Power
 ;;; (DEF-LBP <op> <val>) - defines an operator's Left Binding Power
 
-(defmfun lbp (lex) (cond ((safe-get lex 'lbp)) (t 200.)))
+(defun lbp (lex) (cond ((safe-get lex 'lbp)) (t 200.)))
 
 (defmacro def-lbp (sym val) `(defprop ,sym ,val lbp))
 
@@ -768,7 +778,7 @@
 ;;; (RBP <op>)		 - reads an operator's Right Binding Power
 ;;; (DEF-RBP <op> <val>) - defines an operator's Right Binding Power
 
-(defmfun rbp (lex) (cond ((safe-get lex 'rbp)) (t 200.)))
+(defun rbp (lex) (cond ((safe-get lex 'rbp)) (t 200.)))
 
 (defmacro def-rbp (sym val) `(defprop ,sym ,val rbp))
 
@@ -807,14 +817,14 @@ entire input string to be printed out when an MAXIMA-ERROR occurs."
 ;;;; Misplaced definitions
 
 (defmacro def-operatorp ()
-  `(defmfun operatorp (lex)
+  `(defun operatorp (lex)
      (and (symbolp lex) (getl lex '(,@(nud-propl) ,@(led-propl))))))
 
 (def-operatorp)
 
 (defmacro def-operatorp1 ()
   ;Defmfun -- used by SYNEX if not others.
-  `(defmfun operatorp1 (lex)
+  `(defun operatorp1 (lex)
      ;; Referenced outside of package: OP-SETUP, DECLARE1
      ;; Use for truth value only, not for return-value.
      (and (symbolp lex) (getl lex '(lbp rbp ,@(nud-propl) ,@(led-propl))))))
@@ -829,7 +839,7 @@ entire input string to be printed out when an MAXIMA-ERROR occurs."
 ;;;
 ;;; If you want rubout processing, be sure to call some stream which knows
 ;;; about such things. Also, I'm figuring that the PROMPT will be
-;;; an atribute of the stream which somebody can hack before calling
+;;; an attribute of the stream which somebody can hack before calling
 ;;; MREAD if he wants to.
 
 
@@ -840,7 +850,7 @@ entire input string to be printed out when an MAXIMA-ERROR occurs."
       (and *parse-window* (setf (car *parse-window*) nil
 				*parse-window* (cdr *parse-window*)))
       (princ *mread-prompt*)
-      (force-output))
+      (finish-output))
     (apply 'mread-raw read-args)))
 
 (defun mread-prompter (stream char)
@@ -1140,9 +1150,19 @@ entire input string to be printed out when an MAXIMA-ERROR occurs."
     (cond ((eq '|$)| (first-c)) (parse-err))		  ; () is illegal
 	  ((or (null (setq right (prsmatch '|$)| '$any))) ; No args to MPROGN??
 	       (cdr right))				  ;  More than one arg.
+	  (when (suspicious-mprogn-p right)
+	    (mtell (intl:gettext "warning: parser: I'll let it stand, but (...) doesn't recognize local variables.~%"))
+	    (mtell (intl:gettext "warning: parser: did you mean to say: block(~M, ...) ?~%") (car right)))
 	   (cons '$any (cons hdr right)))	  ; Return an MPROGN
 	  (t (cons '$any (car right))))))		  ; Optimize out MPROGN
 
+(defun suspicious-mprogn-p (right)
+  ;; Look for a Maxima list of symbols or assignments to symbols.
+  (and ($listp (car right))
+       (every #'(lambda (e) (or (symbolp e)
+                                (and (consp e) (eq (caar e) 'msetq) (symbolp (second e)))))
+              (rest (car right)))))
+
 (def-led (|$(| 200.) (op left)
   (setq left (convert left '$any))		        ;De-reference LEFT
   (if (numberp left) (parse-err))			;number(...) illegal
@@ -1162,7 +1182,7 @@ entire input string to be printed out when an MAXIMA-ERROR occurs."
     (cond ((eq '|$(| (first-c))
 	   (list '$any (mheader '|$'|) (parse '$any 190.)))
 	  ((or (atom (setq right (parse '$any 190.)))
-	       (member (caar right) '(mquote mlist mprog mprogn lambda) :test #'eq))
+	       (member (caar right) '(mquote mlist $set mprog mprogn lambda) :test #'eq))
 	   (list '$any (mheader '|$'|) right))
 	  ((eq 'mqapply (caar right))
 	   (cond ((eq (caaadr right) 'lambda)
@@ -1274,6 +1294,9 @@ entire input string to be printed out when an MAXIMA-ERROR occurs."
 (def-rpos	|$.| $expr)
 (def-mheader	|$.| (mnctimes))
 
+;; Copy properties to noun operator.
+(setf (get '%mnctimes 'op) (get 'mnctimes 'op))
+
 (def-led-equiv	|$*| parse-nary)
 (def-lbp	|$*| 120.)
 ;RBP not needed
@@ -1431,8 +1454,7 @@ entire input string to be printed out when an MAXIMA-ERROR occurs."
 	 (case (first-c)
 	   (($else)   (list t (parse '$any (rbp (pop-c)))))
 	   (($elseif) (parse-condition (pop-c)))
-	   (t ; Note: $false instead of () makes DISPLA suppress display!
-	    (list t '$false)))))
+	   (t         (list t '$false)))))
 
 (def-mheader $do (mdo))
 
@@ -1693,25 +1715,25 @@ entire input string to be printed out when an MAXIMA-ERROR occurs."
 ;; they are all generic common lisp and could be used by
 ;; any Common lisp implementation.
 
+#-gcl
+(defstruct instream
+  stream
+  (line 0 :type fixnum)
+  stream-name)
+
 #-gcl
 (defvar *stream-alist* nil)
 
 #-gcl
 (defun stream-name (path)
-  (let ((tem (errset (namestring (pathname path)))))
-    (car tem)))
+  (let ((errset nil))
+    (car (errset (namestring (pathname path))))))
 
 #-gcl
 (defun instream-name (instr)
   (or (instream-stream-name instr)
       (stream-name (instream-stream instr))))
 
-#-gcl
-(defstruct instream
-  stream
-  (line 0 :type fixnum)
-  stream-name)
-
 ;; (closedp stream) checks if a stream is closed.
 ;; how to do this in common lisp!!
 
@@ -1744,9 +1766,12 @@ entire input string to be printed out when an MAXIMA-ERROR occurs."
 
 
 (defun add-lineinfo (lis)
-  (if (or (atom lis) (and (eq *parse-window* *standard-input*)
-			  (not (find-stream *parse-stream*))))
-			  lis
+  (if (or (atom lis) 
+          (eq *parse-stream* *parse-string-input-stream*) ;; avoid consing *parse-string-input-stream* 
+                                                          ;;   via get-instream to *stream-alist* 
+          (and (eq *parse-window* *standard-input*)
+               (not (find-stream *parse-stream*)) ))
+    lis
     (let* ((st (get-instream *parse-stream*))
  	   (n (instream-line st))
 	   (nam (instream-name st)))
