@@ -230,7 +230,7 @@
 
 ;; Factors expression and reduces exponents by their gcd (via solventhp)
 
-(defmfun solve (*exp *var mult &aux (genvar nil) ($derivsubst nil)
+(defun solve (*exp *var mult &aux (genvar nil) ($derivsubst nil)
 		     (exp (float2rat (mratcheck *exp)))
 		     (*myvar *var) ($savefactors t))
   (prog (factors *has*var genpairs $dontfactor temp symbol *g checkfactors 
@@ -414,7 +414,7 @@
 
 ;; To recursively looks through a list
 ;; structure (the VLIST) for members of the SET appearing in the MACSYMA 
-;; functional position (caar list). Returning an assoc. list of appearence
+;; functional position (caar list). Returning an assoc. list of appearance
 ;; frequencies. Notice the use of EXTEND.
 
 (defun operator-frequency-table (vlist set)
