@@ -12,8 +12,6 @@
 
 (macsyma-module trans5)
 
-(transl-module trans5)
-
 ;;; these are TRANSLATE properies for the FSUBRS in JPG;COMM >
 
 ;;; LDISPLAY is one of the most beastly of all macsyma idiot
@@ -77,13 +75,8 @@
 		       sym))))
 	  expr-args))
 
-
-(eval-when
-    #+gcl (compile load eval)
-    #-gcl (:compile-toplevel :load-toplevel :execute)
-
-    (defstruct (disp-hack-ob (:conc-name nil) (:type list)) ;;it wanted tree but that's illegal
-      left-ob right-ob))
+(defstruct (disp-hack-ob (:conc-name nil) (:type list))
+  left-ob right-ob)
 
 (defun object-for-display-hack (exp)
   (if (atom exp)
@@ -142,38 +135,28 @@
 
 (def%tr $cf (form)
   (setq form (car (tr-args (cdr form))))
-  (push-autoload-def '$cf '(cfeval))
   `($any . (let (($listarith nil))
 	     (cfeval ,form))))
 
 ;;; from TRGRED >
 
 (def%tr $apply1 (form &aux (expr (tr-gensym)) (rules (tr-gensym)))
-  (push-autoload-def '$apply1 '(apply1))
   `($any  . (do ((,expr ,(dtranslate (cadr form))
 			(apply1 ,expr (car ,rules) 0))
 		 (,rules ',(cddr form) (cdr ,rules)))
 		((null ,rules) ,expr))))
 
 (def%tr $apply2 (form)
-  `($any . ((lambda (*rulelist)
-	      (declare (special *rulelist))
-	      (apply2 ,(dtranslate (cadr form)) 0))
-	    ',(cddr form))))
+  `($any . (apply2 ',(cddr form) ,(dtranslate (cadr form)) 0)))
 
 (def%tr $applyb1 (form &aux (expr (tr-gensym)) (rules (tr-gensym)))
-  (push-autoload-def '$applyb1 '(apply1hack))
   `($any . (do ((,expr ,(dtranslate (cadr form))
 		       (car (apply1hack ,expr (car ,rules))))
 		(,rules ',(cddr form) (cdr ,rules)))
 	       ((null ,rules) ,expr))))
 
 (def%tr $applyb2 (form)
-  (push-autoload-def '$applyb2 '(apply2hack))
-  `($any . ((lambda (*rulelist)
-	      (declare (special *rulelist))
-	      (apply2hack ,(dtranslate (cadr form))))
-	    ',(cddr form))))
+  `($any . (car (apply2hack ',(cddr form) ,(dtranslate (cadr form))))))
 
 ;;; this nice translation property written by REH.
 ;;; He is the first macsyma system program to ever
@@ -191,7 +174,7 @@
 		    ((eq (caar var) 'msetq)
 		     `(cons ',(cadr var) ,(dtranslate (caddr var))))
 		    (t (setq tr-abort t)
-		       (tr-tell var "Illegal `buildq' form encountered during translation"))))
+		       (tr-format (intl:gettext "error: found unhandled variable ~:M in 'buildq'.~%") var))))
 					;right thing to do here??
 					;how much error checking does transl do now?
 					; Yes. Not as much as it should! -GJC
